Kino.ETS (Kino v0.19.0)

Copy Markdown View Source

A kino for interactively viewing an ETS table.

Examples

tid = :ets.new(:users, [:set, :public])
Kino.ETS.new(tid)

Kino.ETS.new(:elixir_config)

Summary

Functions

Creates a new kino displaying the given ETS table.

Types

t()

@type t() :: Kino.Table.t()

Functions

new(tid)

@spec new(:ets.tid()) :: t()

Creates a new kino displaying the given ETS table.

Note that private tables cannot be read by an arbitrary process, so the given table must have either public or protected access.