A kino for rendering Mermaid diagrams.
Relation to Kino.Markdown
Mermaid diagrams can also be generated dynamically with Kino.Markdown,
however the output of Kino.Markdown is never persisted in the
notebook source. Kino.Mermaid doesn't have this limitation.
Examples
Kino.Mermaid.new("""
graph TD;
A-->B;
A-->C;
B-->D;
C-->D;
""")
Summary
Functions
Creates a new kino displaying the given Mermaid diagram.
Types
@type t() :: Kino.JS.t()