Functions related to workspace integrations and Livebook apps.
Summary
Functions
Returns information about the running app.
Returns user information for the given connected client id.
Types
Functions
@spec app_info() :: app_info()
Returns information about the running app.
Note that :started_by information is only available for multi-session
apps when the app uses a Livebook Teams workspace.
Multi-session apps can be started with lb_* query parameters. Those parameters
are available in :session_params map.
Unless called from within an app deployment, returns %{type: :none}.
Returns user information for the given connected client id.
Note that this information is only available when the session uses
Livebook Teams workspace, otherwise :not_available error is returned.
If there is no such connected client, :not_found error is returned.